summaryrefslogtreecommitdiffstats
path: root/chrome/renderer/resources/extensions/page_action_custom_bindings.js
diff options
context:
space:
mode:
Diffstat (limited to 'chrome/renderer/resources/extensions/page_action_custom_bindings.js')
-rw-r--r--chrome/renderer/resources/extensions/page_action_custom_bindings.js9
1 files changed, 6 insertions, 3 deletions
diff --git a/chrome/renderer/resources/extensions/page_action_custom_bindings.js b/chrome/renderer/resources/extensions/page_action_custom_bindings.js
index b527374..97a308e 100644
--- a/chrome/renderer/resources/extensions/page_action_custom_bindings.js
+++ b/chrome/renderer/resources/extensions/page_action_custom_bindings.js
@@ -2,12 +2,13 @@
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
-// Custom bindings for the pageAction API.
+// Custom binding for the pageAction API.
+
+var binding = require('binding').Binding.create('pageAction');
-var chromeHidden = requireNative('chrome_hidden').GetChromeHidden();
var setIcon = require('setIcon').setIcon;
-chromeHidden.registerCustomHook('pageAction', function(bindingsAPI) {
+binding.registerCustomHook(function(bindingsAPI) {
var apiFunctions = bindingsAPI.apiFunctions;
apiFunctions.setHandleRequest('setIcon', function(details, callback) {
@@ -15,3 +16,5 @@ chromeHidden.registerCustomHook('pageAction', function(bindingsAPI) {
'page action');
});
});
+
+exports.binding = binding.generate();